@@ -295,9 +295,6 @@ PHP_FUNCTION(stream_socket_accept)
 		}
 		php_stream_to_zval(clistream, return_value);
 	} else {
-		if (peername) {
-			zend_string_release(peername);
-		}
 		php_error_docref(NULL, E_WARNING, "accept failed: %s", errstr ? ZSTR_VAL(errstr) : "Unknown error");
 		RETVAL_FALSE;
 	}
@@ -442,11 +439,6 @@ PHP_FUNCTION(stream_get_contents)
 		Z_PARAM_LONG(desiredpos)
 	ZEND_PARSE_PARAMETERS_END_EX(RETURN_FALSE);
 
-	if (maxlen < 0 && maxlen != (ssize_t)PHP_STREAM_COPY_ALL) {
-		php_error_docref(NULL, E_WARNING, "Length must be greater than or equal to zero, or -1");
-		RETURN_FALSE;
-	}
-
 	php_stream_from_zval(stream, zsrc);
 
 	if (desiredpos >= 0) {
